@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::Nums2WordsModules;
 
-our $VERSION = 0.003; # VERSION
+our $VERSION = 0.004; # VERSION
 
 our $results = [
   [
@@ -9,84 +9,84 @@ our $results = [
     [
       {
         dataset     => 123456789,
-        errors      => 4.4e-08,
+        errors      => 1.3e-08,
         participant => "Lingua::ID::Nums2Words::nums2words",
-        rate        => 32000,
-        samples     => 30,
-        time        => 31,
+        rate        => 25600,
+        samples     => 21,
+        time        => 39,
         vs_slowest  => 1,
       },
       {
         dataset     => 123456789,
-        errors      => 2.6e-08,
+        errors      => 1.3e-08,
         participant => "Lingua::EN::Numbers::num2en",
-        rate        => 50000,
-        samples     => 21,
-        time        => 20,
-        vs_slowest  => 1.55,
+        rate        => 30000,
+        samples     => 20,
+        time        => 33.3,
+        vs_slowest  => 1.17117117,
       },
       {
         dataset     => 123,
-        errors      => 9e-08,
+        errors      => 2.7e-08,
         participant => "Lingua::ID::Nums2Words::nums2words",
-        rate        => 89000,
-        samples     => 23,
-        time        => 11,
-        vs_slowest  => 2.8181818,
+        rate        => 62000,
+        samples     => 20,
+        time        => 16,
+        vs_slowest  => 2.4375,
       },
       {
         dataset     => 123456789,
-        errors      => 1.5e-08,
+        errors      => 2e-08,
         participant => "Lingua::FR::Numbers::number_to_fr",
-        rate        => 110000,
-        samples     => 26,
-        time        => 8.9,
-        vs_slowest  => 3.4831461,
+        rate        => 74000,
+        samples     => 20,
+        time        => 14,
+        vs_slowest  => 2.7857143,
       },
       {
         dataset     => 1,
-        errors      => 1.7e-08,
+        errors      => 5.3e-08,
         participant => "Lingua::ID::Nums2Words::nums2words",
-        rate        => 140000,
+        rate        => 80000,
         samples     => 20,
-        time        => 7.2,
-        vs_slowest  => 4.3055556,
+        time        => 12,
+        vs_slowest  => 3.25,
       },
       {
         dataset     => 123,
-        errors      => 6.7e-09,
+        errors      => 1.7e-08,
         participant => "Lingua::EN::Numbers::num2en",
-        rate        => 200000,
+        rate        => 110000,
         samples     => 20,
-        time        => 5,
-        vs_slowest  => 6.2,
+        time        => 9,
+        vs_slowest  => 4.3333333,
       },
       {
         dataset     => 123,
-        errors      => 4.9e-09,
+        errors      => 2e-08,
         participant => "Lingua::FR::Numbers::number_to_fr",
-        rate        => 290000,
+        rate        => 160000,
+        samples     => 23,
+        time        => 6.2,
+        vs_slowest  => 6.2903226,
+      },
+      {
+        dataset     => 1,
+        errors      => 7.9e-09,
+        participant => "Lingua::FR::Numbers::number_to_fr",
+        rate        => 210000,
+        samples     => 22,
+        time        => 4.7,
+        vs_slowest  => 8.2978723,
+      },
+      {
+        dataset     => 1,
+        errors      => 3.5e-09,
+        participant => "Lingua::EN::Numbers::num2en",
+        rate        => 2200000,
         samples     => 21,
-        time        => 3.4,
-        vs_slowest  => 9.1176471,
-      },
-      {
-        dataset     => 1,
-        errors      => 1e-08,
-        participant => "Lingua::FR::Numbers::number_to_fr",
-        rate        => 380000,
-        samples     => 20,
-        time        => 2.6,
-        vs_slowest  => 11.923077,
-      },
-      {
-        dataset     => 1,
-        errors      => 4.7e-11,
-        participant => "Lingua::EN::Numbers::num2en",
-        rate        => 2790000,
-        samples     => 20,
-        time        => 0.359,
-        vs_slowest  => 86.3509749,
+        time        => 0.44,
+        vs_slowest  => 88.636364,
       },
     ],
     {
@@ -134,7 +134,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -157,7 +156,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -165,20 +163,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -187,30 +181,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2840.632,
-                                              stepping                     => 4,
+                                              speed                        => 3284.667,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -249,7 +229,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -272,7 +251,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -280,20 +258,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -302,30 +276,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => "2791.140",
-                                              stepping                     => 4,
+                                              speed                        => 3281.882,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -364,7 +324,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -387,7 +346,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -395,20 +353,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -417,30 +371,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2774.898,
-                                              stepping                     => 4,
+                                              speed                        => 3265.292,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -479,7 +419,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -502,7 +441,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -510,20 +448,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -532,36 +466,22 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2873.664,
-                                              stepping                     => 4,
+                                              speed                        => 3283.335,
+                                              stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.251703023910522,
+      "func.elapsed_time"              => 0.233253955841064,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__"                          => 1.034,
+                                            "__PACKAGE__"                          => 1.036,
                                             "Bencher::Scenario::Nums2WordsModules" => undef,
                                             "Benchmark::Dumb"                      => "0.10",
                                             "Devel::Platform::Info"                => 0.16,
@@ -575,24 +495,24 @@ our $results = [
       "func.permute"                   => ["perl", ["perl"], "participant", [0, 1, 2], "dataset", [0, 1, 2]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "rosa",
+                                            codename => "jessie",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.19.0-32-generic",
+                                            kernel   => "linux-3.16.0-4-amd64",
                                             kname    => "Linux",
-                                            kvers    => "3.19.0-32-generic",
+                                            kvers    => "3.16.0-4-amd64",
                                             osflag   => "linux",
-                                            oslabel  => "LinuxMint",
+                                            oslabel  => "Debian",
                                             osname   => "GNU/Linux",
-                                            osvers   => 17.3,
+                                            osvers   => "8.0",
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
-                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
+                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.19.0-32-generic",
+                                                          "uname -r"        => "3.16.0-4-amd64",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
@@ -602,9 +522,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1468292304,
       "func.scenario_module_sha1sum"   => "0f32dd461400ad47bc5fbb5df10396b32aa79af0",
       "func.scenario_module_sha256sum" => "2f9c7cc6d1e4919bde7668fbf68827e87607cf88e1372ec5da19de00cf5317f9",
-      "func.time_end"                  => 1485323855.76512,
+      "func.time_end"                  => 1497004228.21147,
       "func.time_factor"               => 1,
-      "func.time_start"                => 1485323855.51341,
+      "func.time_start"                => 1497004227.97822,
       "table.field_aligns"             => [
                                             "left",
                                             "left",
